pub enum HwClusterMode {
Pin,
Unpin,
}Expand description
Whether to pin nodes to the target cluster or unpin them back to the parent.
Variants
Pin
Move nodes from the parent cluster into the target cluster.
Unpin
Move nodes back from the target cluster to the parent cluster.