pub async fn post_power(
ctx: RequestCtx,
__arg1: Json<PowerRequest>,
) -> Result<impl IntoResponse, (StatusCode, Json<ErrorResponse>)>Expand description
POST /api/v1/power — power on, off, or reset nodes or all members of a cluster.
pub async fn post_power(
ctx: RequestCtx,
__arg1: Json<PowerRequest>,
) -> Result<impl IntoResponse, (StatusCode, Json<ErrorResponse>)>POST /api/v1/power — power on, off, or reset nodes or all members of a cluster.