pub struct AddNodesToGroupResponse {
pub added: Vec<String>,
pub removed: Vec<String>,
}Expand description
Response for POST /groups/{name}/members.
Fields
added: Vec<String>Xnames that were added to the group as part of this request.
removed: Vec<String>Xnames that were removed from the group as part of this request.